@@ -8,6 +8,9 @@ ETHNET = "https://api.etherscan.io"
 POLYGONNET = "https://api.polygonscan.com"
 BSCNET = "https://api.bscscan.com/"
 
+ETHERSCAN_URL = "https://etherscan.io"
+POLYSCAN_URL = "https://polygonscan.com"
+
 COIN_GECHO_CHAIN_DATA = {
     ETH_CHAIN: {
         "chain_id": "ethereum",
